@@ -17,6 +17,7 @@
 
 pp_awi <- function(target, source, sid, spop, point = FALSE) {
 
+  # calc area
   target$pp_a <- as.vector(sf::st_area(target))
 
   if (point) {
@@ -67,6 +68,7 @@ pp_awi <- function(target, source, sid, spop, point = FALSE) {
 #'
 pp_vwi <- function(target, source, sid, spop, volume, point = FALSE) {
 
+  # calc volume
   target$pp_a <- as.vector(sf::st_area(target)) * target[, volume, drop = T]
 
   if (point) {
@@ -106,6 +108,7 @@ pp_vwi <- function(target, source, sid, spop, volume, point = FALSE) {
 #' @param source an object of class \code{sf}
 #' @param sid source id
 #' @param spop source population
+#' @param volume target volume (height or number of floors)
 #' @param ancillary target ancillary information
 #' @param point whether to use point geometries
 #'
@@ -117,9 +120,14 @@ pp_vwi <- function(target, source, sid, spop, volume, point = FALSE) {
 #'     using bdi
 #' @noRd
 #'
-pp_bdi <- function(target, source, sid, spop, ancillary, point = FALSE) {
+pp_bdi <- function(target, source, sid, spop, volume = NULL, ancillary, point = FALSE) {
+
+  if (is.null(volume)) {
+    target$pp_a <- as.vector(sf::st_area(target)) * target[, ancillary, drop = T]
+  } else {
+    target$pp_a <- as.vector(sf::st_area(target)) * target[, ancillary, drop = T] * target[, volume, drop = T]
+  }
 
-  target$pp_a <- as.vector(sf::st_area(target)) * target[, ancillary, drop = T]
 
   if (point) {
     target <- sf::st_centroid(target)
@@ -170,6 +178,7 @@ pp_bdi <- function(target, source, sid, spop, ancillary, point = FALSE) {
 #'
 pp_fdi <- function(target, source, sid, spop, volume, ancillary, point = FALSE) {
 
+  # calc volume
   target$pp_a <- as.vector(sf::st_area(target)) * target[, ancillary, drop = T] * target[, volume, drop = T]
 
   if (point) {
